"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var defaultOptions_1 = require("../defaultOptions");
var urls_1 = require("../utils/urls");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var transformData = function (data, headers, transformFunction) {
    var functionArray = Array.isArray(transformFunction)
        ? transformFunction
        : !!transformFunction
            ? [transformFunction]
            : [];
    return functionArray.reduce(function (acc, value) { return value(acc, headers); }, data);
};
exports.transformData = transformData;
var dispatchRequest = function (config) {
    if (!config.url || !config.method) {
        throw new Error('Invalid request configuration');
    }
    if (config.baseURL && !urls_1.isAbsoluteURL(config.url)) {
        config.url = urls_1.combineURLs(config.baseURL, config.url);
    }
    config.headers = config.headers || {};
    config.data = transformData(config.data, config.headers, config.transformRequest);
    var _a = config.headers, common = _a.common, rest = tslib_1.__rest(_a, ["common"]);
    config.headers = tslib_1.__assign({}, (common || {}), (rest[config.method] || {}), (rest || {}));
    ["delete", "get", "head", "options", "patch", "post", "put"].forEach(function (method) { return delete config.headers[method]; });
    var adapter = config.adapter || defaultOptions_1.defaultOptions.adapter;
    return adapter(config).pipe(operators_1.map(function (response) {
        if (response.type !== "Response") {
            return response;
        }
        var data = response.data, headers = response.headers;
        return tslib_1.__assign({}, response, { data: transformData(data, headers, config.transformResponse) });
    }), operators_1.catchError(function (err) {
        if (!!err && !!err.response && err.response.type === "Response") {
            var _a = err.response, data = _a.data, headers = _a.headers;
            err.response.data = transformData(data, headers, config.transformResponse);
        }
        return rxjs_1.throwError(err);
    }));
};
exports.dispatchRequest = dispatchRequest;
//# sourceMappingURL=dispatchRequest.js.map