"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var base_1 = require("../utils/base");
var urls_1 = require("../utils/urls");
var dispatchRequest_1 = require("./dispatchRequest");
var buildConfig = function (urlOrConfig, config) {
    var baseConfig = (base_1.isString(urlOrConfig) ? config : urlOrConfig) || {};
    if (base_1.isString(urlOrConfig)) {
        baseConfig.url = urlOrConfig;
    }
    return tslib_1.__assign({}, baseConfig, { url: base_1.isString(urlOrConfig) ? urlOrConfig : baseConfig.url, method: baseConfig.method ? baseConfig.method.toLowerCase() : "get" });
};
var Oxid = (function () {
    function Oxid(baseConfig) {
        var _this = this;
        this.baseConfig = baseConfig;
        this.interceptors = {
            request: [],
            response: []
        };
        ["delete", "get", "head", "options"].forEach(function (method) { return (_this[method] = function (url, config) { return _this.request(tslib_1.__assign({}, config, { method: method, url: url })); }); });
        ["post", "put", "patch"].forEach(function (method) {
            return (_this[method] = function (url, data, config) {
                return _this.request(tslib_1.__assign({}, config, { data: data, method: method, url: url }));
            });
        });
    }
    Oxid.prototype.request = function (urlOrConfig, config) {
        var _a;
        var mergedConfig = tslib_1.__assign({}, this.baseConfig, buildConfig(urlOrConfig, config));
        var _b = this.interceptors, request = _b.request, response = _b.response;
        var buildInterceptorOperators = function (interceptors) {
            return interceptors.reduce(function (acc, _a) {
                var next = _a.next, error = _a.error;
                acc.push(operators_1.map(next));
                acc.push(operators_1.catchError(function (err) { return rxjs_1.throwError(error(err)); }));
                return acc;
            }, []);
        };
        return (_a = rxjs_1.of(mergedConfig)).pipe.apply(_a, buildInterceptorOperators(request).concat([operators_1.mergeMap(function (value) { return dispatchRequest_1.dispatchRequest(value); })], buildInterceptorOperators(response)));
    };
    Oxid.prototype.getUri = function (config) {
        var _a = tslib_1.__assign({}, this.baseConfig, buildConfig(config)), url = _a.url, params = _a.params, paramsSerializer = _a.paramsSerializer;
        if (!url) {
            throw new Error("Invalid request configuration");
        }
        return urls_1.buildURL(url, params, paramsSerializer).replace(/^\?/, '');
    };
    return Oxid;
}());
exports.Oxid = Oxid;
//# sourceMappingURL=oxid.js.map