"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var isBuffer = require("is-buffer");
var base_1 = require("./utils/base");
var normalizeHeaderName_1 = require("./utils/normalizeHeaderName");
var DEFAULT_CONTENT_TYPE = {
    'Content-Type': 'application/x-www-form-urlencoded'
};
var setContentTypeIfUnset = function (headers, value) {
    if (!!headers && !headers['Content-Type']) {
        headers['Content-Type'] = value;
    }
};
var getDefaultAdapter = function () { return (base_1.isNode() ? require('./adapters/http') : require('./adapters/xhr')).adapter; };
var validateStatus = function (status) { return status >= 200 && status < 300; };
exports.validateStatus = validateStatus;
var defaultTransformRequest = function (data, headers) {
    normalizeHeaderName_1.normalizeHeaderName(headers, 'Accept');
    normalizeHeaderName_1.normalizeHeaderName(headers, 'Content-Type');
    if (base_1.isFormData(data) || base_1.isArrayBuffer(data) || isBuffer(data) || base_1.isStream(data) || base_1.isFile(data) || base_1.isBlob(data)) {
        return data;
    }
    if (ArrayBuffer.isView(data)) {
        return data.buffer;
    }
    if (base_1.isURLSearchParams(data)) {
        setContentTypeIfUnset(headers, 'application/x-www-form-urlencoded;charset=utf-8');
        return data.toString();
    }
    if (base_1.isObject(data)) {
        setContentTypeIfUnset(headers, 'application/json;charset=utf-8');
        return JSON.stringify(data);
    }
    return data;
};
var defaultTransformResponse = function (data) {
    if (typeof data === 'string') {
        try {
            data = JSON.parse(data);
        }
        catch (e) {
        }
    }
    return data;
};
var defaultOptions = (function () {
    var ret = {
        adapter: getDefaultAdapter(),
        transformRequest: [defaultTransformRequest],
        transformResponse: [defaultTransformResponse],
        xsrfCookieName: 'XSRF-TOKEN',
        xsrfHeaderName: base_1.XSRF_HEADER_NAME,
        maxContentLength: -1,
        validateStatus: validateStatus,
        headers: {
            common: {
                Accept: 'application/json, text/plain, */*'
            }
        }
    };
    ["delete", "get", "head"].forEach(function (method) { return (ret.headers[method] = {}); });
    ["post", "put", "patch"].forEach(function (method) {
        var current = ret.headers[method] || {};
        ret.headers[method] = tslib_1.__assign({}, current, DEFAULT_CONTENT_TYPE);
    });
    return Object.freeze(ret);
})();
exports.defaultOptions = defaultOptions;
//# sourceMappingURL=defaultOptions.js.map