"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var getroot_1 = require("getroot");
var toPrototypeString = function (val) { return Object.prototype.toString.call(val); };
var isNode = function () {
    var proc = getroot_1.root.process;
    if (!!proc && typeof proc === 'object') {
        if (!!proc.versions && typeof proc.versions === 'object') {
            if (typeof proc.versions.node !== 'undefined') {
                return true;
            }
        }
    }
    return false;
};
exports.isNode = isNode;
var isString = function (val) { return typeof val === 'string'; };
exports.isString = isString;
var isNumber = function (val) { return typeof val === 'number'; };
exports.isNumber = isNumber;
var isObject = function (val) { return val !== null && typeof val === 'object'; };
exports.isObject = isObject;
var isDate = function (val) { return !!val && !!val.toString && toPrototypeString(val) === '[object Date]'; };
exports.isDate = isDate;
var isFunction = function (val) { return toString.call(val) === '[object Function]'; };
exports.isFunction = isFunction;
var isStream = function (val) { return isObject(val) && isFunction(val.pipe); };
exports.isStream = isStream;
var isArrayBuffer = function (val) { return toString.call(val) === '[object ArrayBuffer]'; };
exports.isArrayBuffer = isArrayBuffer;
var isFormData = function (val) { return typeof FormData !== 'undefined' && val instanceof FormData; };
exports.isFormData = isFormData;
var isFile = function (val) { return toString.call(val) === '[object File]'; };
exports.isFile = isFile;
var isBlob = function (val) { return toString.call(val) === '[object Blob]'; };
exports.isBlob = isBlob;
var isURLSearchParams = function (val) {
    return isNode()
        ? require('./node/isURLSearchParams').isURLSearchParams(val)
        : require('./browser/isURLSearchParams').isURLSearchParams(val);
};
exports.isURLSearchParams = isURLSearchParams;
var isStandardBrowserEnv = function () {
    if (isNode()) {
        return false;
    }
    if (typeof navigator !== 'undefined' &&
        (navigator.product === 'ReactNative' || navigator.product === 'NativeScript' || navigator.product === 'NS')) {
        return false;
    }
    return typeof window !== 'undefined' && typeof document !== 'undefined';
};
exports.isStandardBrowserEnv = isStandardBrowserEnv;
var pick = function (value, props) {
    return props.reduce(function (acc, prop) {
        if (value[prop]) {
            acc[prop] = value[prop];
        }
        return acc;
    }, {});
};
exports.pick = pick;
var XSRF_HEADER_NAME = 'X-XSRF-TOKEN';
exports.XSRF_HEADER_NAME = XSRF_HEADER_NAME;
var XSSI_PREFIX = /^\)\]\}',?\n/;
exports.XSSI_PREFIX = XSSI_PREFIX;
//# sourceMappingURL=base.js.map