import * as tslib_1 from "tslib";
import { defaultOptions } from '../defaultOptions';
import { combineURLs, isAbsoluteURL } from '../utils/urls';
import { throwError } from 'rxjs';
import { catchError, map } from 'rxjs/operators';
var transformData = function (data, headers, transformFunction) {
    var functionArray = Array.isArray(transformFunction)
        ? transformFunction
        : !!transformFunction
            ? [transformFunction]
            : [];
    return functionArray.reduce(function (acc, value) { return value(acc, headers); }, data);
};
var dispatchRequest = function (config) {
    if (!config.url || !config.method) {
        throw new Error('Invalid request configuration');
    }
    if (config.baseURL && !isAbsoluteURL(config.url)) {
        config.url = combineURLs(config.baseURL, config.url);
    }
    config.headers = config.headers || {};
    config.data = transformData(config.data, config.headers, config.transformRequest);
    var _a = config.headers, common = _a.common, rest = tslib_1.__rest(_a, ["common"]);
    config.headers = tslib_1.__assign({}, (common || {}), (rest[config.method] || {}), (rest || {}));
    ["delete", "get", "head", "options", "patch", "post", "put"].forEach(function (method) { return delete config.headers[method]; });
    var adapter = config.adapter || defaultOptions.adapter;
    return adapter(config).pipe(map(function (response) {
        if (response.type !== "Response") {
            return response;
        }
        var data = response.data, headers = response.headers;
        return tslib_1.__assign({}, response, { data: transformData(data, headers, config.transformResponse) });
    }), catchError(function (err) {
        if (!!err && !!err.response && err.response.type === "Response") {
            var _a = err.response, data = _a.data, headers = _a.headers;
            err.response.data = transformData(data, headers, config.transformResponse);
        }
        return throwError(err);
    }));
};
export { transformData, dispatchRequest };
//# sourceMappingURL=dispatchRequest.js.map