import * as tslib_1 from "tslib";
import * as isBuffer from 'is-buffer';
import { isArrayBuffer, isBlob, isFile, isFormData, isNode, isObject, isStream, isURLSearchParams, XSRF_HEADER_NAME } from './utils/base';
import { normalizeHeaderName } from './utils/normalizeHeaderName';
var DEFAULT_CONTENT_TYPE = {
    'Content-Type': 'application/x-www-form-urlencoded'
};
var setContentTypeIfUnset = function (headers, value) {
    if (!!headers && !headers['Content-Type']) {
        headers['Content-Type'] = value;
    }
};
var getDefaultAdapter = function () { return (isNode() ? require('./adapters/http') : require('./adapters/xhr')).adapter; };
var validateStatus = function (status) { return status >= 200 && status < 300; };
var defaultTransformRequest = function (data, headers) {
    normalizeHeaderName(headers, 'Accept');
    normalizeHeaderName(headers, 'Content-Type');
    if (isFormData(data) || isArrayBuffer(data) || isBuffer(data) || isStream(data) || isFile(data) || isBlob(data)) {
        return data;
    }
    if (ArrayBuffer.isView(data)) {
        return data.buffer;
    }
    if (isURLSearchParams(data)) {
        setContentTypeIfUnset(headers, 'application/x-www-form-urlencoded;charset=utf-8');
        return data.toString();
    }
    if (isObject(data)) {
        setContentTypeIfUnset(headers, 'application/json;charset=utf-8');
        return JSON.stringify(data);
    }
    return data;
};
var defaultTransformResponse = function (data) {
    if (typeof data === 'string') {
        try {
            data = JSON.parse(data);
        }
        catch (e) {
        }
    }
    return data;
};
var defaultOptions = (function () {
    var ret = {
        adapter: getDefaultAdapter(),
        transformRequest: [defaultTransformRequest],
        transformResponse: [defaultTransformResponse],
        xsrfCookieName: 'XSRF-TOKEN',
        xsrfHeaderName: XSRF_HEADER_NAME,
        maxContentLength: -1,
        validateStatus: validateStatus,
        headers: {
            common: {
                Accept: 'application/json, text/plain, */*'
            }
        }
    };
    ["delete", "get", "head"].forEach(function (method) { return (ret.headers[method] = {}); });
    ["post", "put", "patch"].forEach(function (method) {
        var current = ret.headers[method] || {};
        ret.headers[method] = tslib_1.__assign({}, current, DEFAULT_CONTENT_TYPE);
    });
    return Object.freeze(ret);
})();
export { defaultOptions, validateStatus };
//# sourceMappingURL=defaultOptions.js.map