import { root } from 'getroot';
var toPrototypeString = function (val) { return Object.prototype.toString.call(val); };
var isNode = function () {
    var proc = root.process;
    if (!!proc && typeof proc === 'object') {
        if (!!proc.versions && typeof proc.versions === 'object') {
            if (typeof proc.versions.node !== 'undefined') {
                return true;
            }
        }
    }
    return false;
};
var isString = function (val) { return typeof val === 'string'; };
var isNumber = function (val) { return typeof val === 'number'; };
var isObject = function (val) { return val !== null && typeof val === 'object'; };
var isDate = function (val) { return !!val && !!val.toString && toPrototypeString(val) === '[object Date]'; };
var isFunction = function (val) { return toString.call(val) === '[object Function]'; };
var isStream = function (val) { return isObject(val) && isFunction(val.pipe); };
var isArrayBuffer = function (val) { return toString.call(val) === '[object ArrayBuffer]'; };
var isFormData = function (val) { return typeof FormData !== 'undefined' && val instanceof FormData; };
var isFile = function (val) { return toString.call(val) === '[object File]'; };
var isBlob = function (val) { return toString.call(val) === '[object Blob]'; };
var isURLSearchParams = function (val) {
    return isNode()
        ? require('./node/isURLSearchParams').isURLSearchParams(val)
        : require('./browser/isURLSearchParams').isURLSearchParams(val);
};
var isStandardBrowserEnv = function () {
    if (isNode()) {
        return false;
    }
    if (typeof navigator !== 'undefined' &&
        (navigator.product === 'ReactNative' || navigator.product === 'NativeScript' || navigator.product === 'NS')) {
        return false;
    }
    return typeof window !== 'undefined' && typeof document !== 'undefined';
};
var pick = function (value, props) {
    return props.reduce(function (acc, prop) {
        if (value[prop]) {
            acc[prop] = value[prop];
        }
        return acc;
    }, {});
};
var XSRF_HEADER_NAME = 'X-XSRF-TOKEN';
var XSSI_PREFIX = /^\)\]\}',?\n/;
export { isNode, isFormData, isFile, isFunction, isBlob, isString, isObject, isArrayBuffer, isNumber, isStream, isDate, isURLSearchParams, isStandardBrowserEnv, XSRF_HEADER_NAME, XSSI_PREFIX, pick };
//# sourceMappingURL=base.js.map