import { isDate, isObject, isStandardBrowserEnv, isString, isURLSearchParams } from './base';
var encode = function (val) {
    return encodeURIComponent(val)
        .replace(/%40/gi, '@')
        .replace(/%3A/gi, ':')
        .replace(/%24/g, '$')
        .replace(/%2C/gi, ',')
        .replace(/%20/g, '+')
        .replace(/%5B/gi, '[')
        .replace(/%5D/gi, ']');
};
var buildURL = function (url, params, paramsSerializer) {
    if (!params) {
        return url;
    }
    var constructUrl = function (serializedParams) {
        if (!serializedParams) {
            return url;
        }
        var hashmarkIndex = url.indexOf('#');
        var sliced = url.indexOf('#') !== -1 ? url.slice(0, hashmarkIndex) : url;
        return "" + sliced + (sliced.indexOf('?') === -1 ? '?' : '&') + serializedParams;
    };
    if (paramsSerializer) {
        return constructUrl(paramsSerializer(params));
    }
    else if (isURLSearchParams(params)) {
        return constructUrl(params.toString());
    }
    else {
        var parts = Object.keys(params)
            .map(function (key) { return [key, params[key]]; })
            .filter(function (_a) {
            var value = _a[1];
            return value !== null && typeof value !== 'undefined';
        })
            .reduce(function (acc, _a) {
            var key = _a[0], value = _a[1];
            var _b = Array.isArray(value)
                ? [key + "[]", value]
                : [key, [value]], updatedKey = _b[0], updatedValue = _b[1];
            var encoded = updatedValue.map(function (v) {
                return encode(updatedKey) + "=" + encode(isDate(v) ? v.toISOString() : isObject(v) ? JSON.stringify(v) : v);
            });
            return acc.concat(encoded);
        }, []);
        return constructUrl(parts.join('&'));
    }
};
var combineURLs = function (base, relative) {
    return relative ? base.replace(/\/+$/, '') + '/' + relative.replace(/^\/+/, '') : base;
};
var resolveURL = function (url) {
    var msie = /(msie|trident)/i.test(navigator.userAgent);
    var urlParsingNode = document.createElement('a');
    if (msie) {
        urlParsingNode.setAttribute('href', url);
    }
    var href = msie ? urlParsingNode.href : url;
    urlParsingNode.setAttribute('href', href);
    return {
        href: urlParsingNode.href,
        protocol: urlParsingNode.protocol ? urlParsingNode.protocol.replace(/:$/, '') : '',
        host: urlParsingNode.host,
        search: urlParsingNode.search ? urlParsingNode.search.replace(/^\?/, '') : '',
        hash: urlParsingNode.hash ? urlParsingNode.hash.replace(/^#/, '') : '',
        hostname: urlParsingNode.hostname,
        port: urlParsingNode.port,
        pathname: urlParsingNode.pathname.charAt(0) === '/' ? urlParsingNode.pathname : '/' + urlParsingNode.pathname
    };
};
var isAbsoluteURL = function (url) { return /^([a-z][a-z\d\+\-\.]*:)?\/\//i.test(url); };
var isURLSameOrigin = isStandardBrowserEnv()
    ? (function () {
        var originURL = resolveURL(window.location.href);
        return function (requestURL) {
            var parsed = isString(requestURL) ? resolveURL(requestURL) : requestURL;
            return parsed.protocol === originURL.protocol && parsed.host === originURL.host;
        };
    })()
    : function () { return true; };
export { buildURL, combineURLs, isAbsoluteURL, isURLSameOrigin };
//# sourceMappingURL=urls.js.map