/// <reference types="node" />
import { Stream } from 'stream';
/**
 * Naïvely detect if running environment if node
 * Note this'll return true on Electron's renderer process as well
 */
declare const isNode: () => boolean;
/**
 * Determine if a value is a String
 *
 * @param {any} val The value to test
 * @returns {boolean} True if value is a String, otherwise false
 */
declare const isString: (val: any) => val is string;
/**
 * Determine if a value is a Number
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Number, otherwise false
 */
declare const isNumber: (val: any) => val is number;
/**
 * Determine if a value is an Object
 *
 * @param unknown val The value to test
 * @returns boolean True if value is an Object, otherwise false
 */
declare const isObject: (val: unknown) => boolean;
/**
 * Determine if a value is a Date
 *
 * @param any val The value to test
 * @returns boolean True if value is a Date, otherwise false
 */
declare const isDate: (val: any) => val is Date;
/**
 * Determine if a value is a Function
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Function, otherwise false
 */
declare const isFunction: (val: any) => val is Function;
/**
 * Determine if a value is a Stream
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Stream, otherwise false
 */
declare const isStream: (val: any) => val is Stream;
/**
 * Determine if a value is an ArrayBuffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an ArrayBuffer, otherwise false
 */
declare const isArrayBuffer: (val: any) => val is ArrayBuffer;
/**
 * Determine if a value is a FormData
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an FormData, otherwise false
 */
declare const isFormData: (val: any) => val is FormData;
/**
 * Determine if a value is a File
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a File, otherwise false
 */
declare const isFile: (val: any) => boolean;
/**
 * Determine if a value is a Blob
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Blob, otherwise false
 */
declare const isBlob: (val: any) => boolean;
/**
 * Determine if a value is a URLSearchParams object
 *
 * @param unknown val The value to test
 * @returns boolean True if value is a URLSearchParams object, otherwise false
 */
declare const isURLSearchParams: (val: unknown) => any;
/**
 * Determine if we're running in a standard browser environment
 *
 * This allows to run in a web worker, and react-native.
 * Both environments support XMLHttpRequest, but not fully standard globals.
 *
 * web workers:
 *  typeof window -> undefined
 *  typeof document -> undefined
 *
 * react-native:
 *  navigator.product -> 'ReactNative'
 * nativescript
 *  navigator.product -> 'NativeScript' or 'NS'
 */
declare const isStandardBrowserEnv: () => boolean;
/**
 * Naïve implementation of `pick<T, U>()`.
 */
declare const pick: (value: Record<string, any>, props: string[]) => {};
declare const XSRF_HEADER_NAME = "X-XSRF-TOKEN";
declare const XSSI_PREFIX: RegExp;
export { isNode, isFormData, isFile, isFunction, isBlob, isString, isObject, isArrayBuffer, isNumber, isStream, isDate, isURLSearchParams, isStandardBrowserEnv, XSRF_HEADER_NAME, XSSI_PREFIX, pick };
//# sourceMappingURL=base.d.ts.map