/**
 * Build a URL by appending params to the end
 *
 * @param {string} url The base of the url (e.g., http://www.google.com)
 * @param {Record<string, any>} [params] The params to be appended
 * @param {(}params: Record<string, string>)} => string [paramsSerializer] custom serializer
 * @returns {string} The formatted url
 */
declare const buildURL: (url: string, params?: Record<string, any> | undefined, paramsSerializer?: ((params: Record<string, any>) => string) | undefined) => string;
/**
 * Creates a new URL by combining the specified URLs
 *
 * @param {string} baseURL The base URL
 * @param {string} relativeURL The relative URL
 * @returns {string} The combined URL
 */
declare const combineURLs: (base: string, relative: string) => string;
/**
 * Determines whether the specified URL is absolute
 *
 * @param {string} url The URL to test
 * @returns {boolean} True if the specified URL is absolute, otherwise false
 *
 * A URL is considered absolute if it begins with "<scheme>://" or "//" (protocol-relative URL).
 * RFC 3986 defines scheme name as a sequence of characters beginning with a letter and followed
 * by any combination of letters, digits, plus, period, or hyphen.
 */
declare const isAbsoluteURL: (url: string) => boolean;
/**
 * Determine if a URL shares the same origin as the current location
 *
 * @param {String} requestURL The URL to test
 * @returns {boolean} True if URL shares the same origin, otherwise false
 */
declare const isURLSameOrigin: (requestURL: string | Partial<{
    href: string;
    protocol: string;
    host: string;
    search: string;
    hash: string;
    hostname: string;
    port: string;
    pathname: string;
}>) => boolean;
export { buildURL, combineURLs, isAbsoluteURL, isURLSameOrigin };
//# sourceMappingURL=urls.d.ts.map